"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.publishAndAcknowledgeMessage = void 0;
const bluebird_1 = __importDefault(require("bluebird"));
const redis_smq_1 = require("redis-smq");
const { promisifyAll, delay } = bluebird_1.default;
function publishAndAcknowledgeMessage(queue) {
    return __awaiter(this, void 0, void 0, function* () {
        const producer = promisifyAll(new redis_smq_1.Producer());
        yield producer.runAsync();
        const consumer = promisifyAll(new redis_smq_1.Consumer());
        yield consumer.runAsync();
        const message = new redis_smq_1.ProducibleMessage();
        message.setBody({ hello: 'world' }).setQueue(queue);
        const ids = yield producer.produceAsync(message);
        const acknowledgedMessages = [];
        const eventBus = promisifyAll(new redis_smq_1.EventBusRedisInstance());
        const eventBusInstance = yield eventBus.getSetInstanceAsync();
        eventBusInstance.on('consumer.consumeMessage.messageAcknowledged', (messageId) => {
            acknowledgedMessages.push(messageId);
        });
        yield consumer.consumeAsync(queue, (msg, cb) => {
            cb();
        });
        while (JSON.stringify(ids.sort()) !== JSON.stringify(acknowledgedMessages.sort())) {
            yield delay(1000);
        }
        yield producer.shutdownAsync();
        yield consumer.shutdownAsync();
        yield eventBus.shutdownAsync();
        return ids;
    });
}
exports.publishAndAcknowledgeMessage = publishAndAcknowledgeMessage;
//# sourceMappingURL=publish-and-acknowledge-message.js.map