import bluebird from 'bluebird';
import { Consumer, EventBusRedisInstance, Producer, ProducibleMessage, } from 'redis-smq';
const { promisifyAll, delay } = bluebird;
export async function publishAndAcknowledgeMessage(queue) {
    const producer = promisifyAll(new Producer());
    await producer.runAsync();
    const consumer = promisifyAll(new Consumer());
    await consumer.runAsync();
    const message = new ProducibleMessage();
    message.setBody({ hello: 'world' }).setQueue(queue);
    const ids = await producer.produceAsync(message);
    const acknowledgedMessages = [];
    const eventBus = promisifyAll(new EventBusRedisInstance());
    const eventBusInstance = await eventBus.getSetInstanceAsync();
    eventBusInstance.on('consumer.consumeMessage.messageAcknowledged', (messageId) => {
        acknowledgedMessages.push(messageId);
    });
    await consumer.consumeAsync(queue, (msg, cb) => {
        cb();
    });
    while (JSON.stringify(ids.sort()) !== JSON.stringify(acknowledgedMessages.sort())) {
        await delay(1000);
    }
    await producer.shutdownAsync();
    await consumer.shutdownAsync();
    await eventBus.shutdownAsync();
    return ids;
}
//# sourceMappingURL=publish-and-acknowledge-message.js.map