import bluebird from 'bluebird';
import { Consumer, EventBusRedisInstance, Producer, ProducibleMessage, } from 'redis-smq';
const { delay, promisifyAll } = bluebird;
export async function publishAndDeadLetterMessage(queue) {
    const producer = promisifyAll(new Producer());
    await producer.runAsync();
    const consumer = promisifyAll(new Consumer());
    await consumer.runAsync();
    const message = new ProducibleMessage();
    message.setBody({ hello: 'world' }).setQueue(queue).setRetryThreshold(0);
    const ids = await producer.produceAsync(message);
    const deadLetteredMessages = [];
    const eventBus = promisifyAll(new EventBusRedisInstance());
    const eventBusInstance = await eventBus.getSetInstanceAsync();
    eventBusInstance.on('consumer.consumeMessage.messageDeadLettered', (messageId) => {
        deadLetteredMessages.push(messageId);
    });
    await consumer.consumeAsync(queue, (msg, cb) => {
        cb(new Error());
    });
    while (JSON.stringify(ids.sort()) !== JSON.stringify(deadLetteredMessages.sort())) {
        await delay(1000);
    }
    await producer.shutdownAsync();
    await consumer.shutdownAsync();
    await eventBus.shutdownAsync();
    return ids;
}
//# sourceMappingURL=publish-and-dead-letter-message.js.map